@@ -84,7 +84,7 @@ class RedisCustomer(object):
             self._threadpool = specify_threadpool if specify_threadpool else CustomThreadPoolExecutor(threads_num)
         self.max_retry_times = max_retry_times
         self.func_timeout = func_timeout
-        self.is_support_mutil_param = True
+        self.is_support_mutil_param = is_support_mutil_param
         self.qps = qps
 
     def _start_consuming_message_thread(self):
@@ -122,10 +122,11 @@ class RedisCustomer(object):
         if (platform.system() == 'Darwin' or platform.system() == 'Linux') and self.process_num > 1:
             for i in range(0, min(self.process_num, cpu_count)):
                 logger.info(
-                    f'start consuming message  process:{i+1},{self.customer_type}_num:{self.threads_num},system:{platform.system()}')
+                    f'start consuming message  process:{i + 1},{self.customer_type}_num:{self.threads_num},system:{platform.system()}')
                 Process(target=self._start_consuming_message_thread).start()
         else:
-            logger.info(f'start consuming message {self.customer_type}, {self.customer_type}_num:{self.threads_num},system:{platform.system()}')
+            logger.info(
+                f'start consuming message {self.customer_type}, {self.customer_type}_num:{self.threads_num},system:{platform.system()}')
             threading.Thread(target=self._start_consuming_message_thread).start()
 
     def _consuming_exception_retry(self, message):
@@ -202,13 +203,13 @@ class RedisPublish(object):
     def publish_redispy_list(self, msgs: list):
         """
         批量写入redis队列
-        :param msgs: 待写入字符串列表
+        :param msgs: 待写入列表数据
         :return: 
         """
         if self.middleware == RedisQueue.middleware_name:
             pipe = self._redis_quenen.getdb().pipeline()
             for id in msgs:
-                pipe.lpush(self._redis_quenen.queue_name, id)
+                pipe.lpush(self._redis_quenen.queue_name, json.dumps(id))
                 if len(pipe) == self.max_push_size:
                     pipe.execute()
                     logger.info(str(self.max_push_size).center(20, '*') + 'commit')
@@ -228,7 +229,6 @@ class RedisPublish(object):
         if self._pipe is None:
             self._pipe = self._redis_quenen.getdb().pipeline()
         self._local_quenen.put(msg)
-        # logger.info(f'self._local_quenen.size:{self._local_quenen.qsize()}')
         if self._local_quenen.qsize() >= self.max_push_size:
             try:
                 while self._local_quenen.qsize() > 0:
@@ -245,6 +245,13 @@ class RedisPublish(object):
         """
         self._redis_quenen.clear()
 
+    def qsize(self):
+        """
+        获取当前队列任务数量
+        :return: int 队列中任务数量
+        """
+        return self._redis_quenen.qsize()
+
 
 def kill_owner_process():
     try:
@@ -278,8 +285,9 @@ if __name__ == '__main__':
 
     # #### 2.发布消费多参数类型任务
     for zz in range(1, 501):
-        # 写入字典任务 {"c":zz,"b":zz,"a":zz}
-        RedisPublish(queue_name='test2').publish_redispy(c=str(zz), b=str(zz), a=str(zz))
+        # 写入字典任务 {"a":zz,"b":zz,"c":zz}
+        param = {"a": zz, "b": zz, "c": zz}
+        RedisPublish(queue_name='test2').publish_redispy(param)
 
 
     def print_msg_dict(a, b, c):
@@ -291,11 +299,11 @@ if __name__ == '__main__':
                   qps=50).start_consuming_message()
 
     # #### 3.批量提交任务
-    result = [str(i)*10 for i in range(1, 501)]
+    result = [{'a': i, 'b': i, 'c': i} for i in range(1, 501)]
     # 批量提交任务 queue_name提交任务队列名称 max_push_size每次批量提交记录数(默认值50)
     RedisPublish(queue_name='test3', max_push_size=100).publish_redispy_list(result)
     # 消费者类型 string 支持('thread','gevent') 默认thread
-    RedisCustomer(queue_name='test3', consuming_function=print_msg_str, customer_type='gevent',
+    RedisCustomer(queue_name='test3', consuming_function=print_msg_dict(), customer_type='gevent',
                   qps=50).start_consuming_message()
 
     # #### 4.切换任务队列中间件为sqlite(默认为redis)
